/*

	Plots data and a switched model estimated by klinreg 

	(actually, this program only creates a set of data files 
	 and a 'gnuplot script' to plot them)
	 
	 
	-- by F. Lauer, 2011.
*/


#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>
#define MAXFIRSTLINELENGTH 200

/*
	main function
*/
int main(int argc, char *argv[]) {
	
	
	FILE *fp; // prediction file
	FILE *fd,*ft;	// data file and true labels file
	
	int i,j,k,n,p,N,label;
	
	
	FILE **plotfiles;
	FILE *fs;
	
	char datafile[250];
	char labelfile[250];
	char predfile[250];
	char plotfile[250];
	char buf[250];
	double x;
	
	if(argc < 4) {
		printf("Usage: plot datafile file.pred n\n");
		exit(0);
	}

	// Get data filename
	strcpy(datafile, argv[1]);
	// Get labels filename
	strcpy(labelfile, datafile);
	strcat(labelfile, ".labels");
	
	// Get pred filename
	strcpy(predfile, argv[2]);
	// Get number of modes	
	n = atoi(argv[3]);	

	plotfiles = (FILE **)malloc(sizeof(FILE *) * n);
	
	if((fd = fopen(datafile, "r")) == NULL) {
		printf("Wrong filename, abording.\n");
		return 0;
	}
	if((ft = fopen(labelfile, "r")) == NULL) {
		printf("Wrong filename, abording.\n");
		return 0;
	}
	if((fp = fopen(predfile, "r")) == NULL) {
		printf("Wrong filename, abording.\n");
		return 0;
	}
	for(j=0;j<n;j++) {
		sprintf(plotfile, "plotfile%d",j);
		if((plotfiles[j] = fopen(plotfile, "w")) == NULL) {
			printf("Wrong filename, abording.\n");
			return 0;
		}
	}
	
	// Handle first line
	if (fgets(buf, MAXFIRSTLINELENGTH, fd) == NULL) {
		fclose(fd);
		printf("Error in data file, abording.\n");
		return 0;
	}
	sscanf(buf,"%d%d", &N,&p);
	printf("N= %d, p = %d\n",N,p);
	
	// Start transcript
	for(i=0;i<N;i++) {
		fscanf(ft,"%d",&label);
		
		for(k=0;k<p;k++) {
			fscanf(fd,"%lf",&x);
			fprintf(plotfiles[label], "%lf ",x);
		}
		
		fscanf(fd,"%lf",&x); 
		fprintf(plotfiles[label], "%lf ",x); // y_i
		for(j=0;j<n;j++) {
			fscanf(fp,"%lf",&x); 
			fprintf(plotfiles[label], "%lf ",x); // f_j(x_i)
		}
		fscanf(fp,"%lf",&x); // trash f(x_i)
		fscanf(fp,"%d",&label); // trash predicted label
		fprintf(plotfiles[label], "\n ");

	}
	
	// Close files
	fclose(fp);
	fclose(ft);
	fclose(fd);
	
	for(j=0;j<n;j++) 
		fclose(plotfiles[j]);
		
	// Make script
	if((fs = fopen("plotscript", "w")) == NULL) {
		printf("Wrong filename, abording.\n");
		return 0;
	}
	fprintf(fs,"set xrange [-10:10]\n");
	fprintf(fs,"set yrange [-20:20]\n");
	fprintf(fs,"set nokey\n");
	fprintf(fs,"set multiplot\n");
	
	for(j=0;j<n;j++) {
		// Plot data
		fprintf(fs, "plot 'plotfile%d' using 1:%d lt %d with points\n",j,p+1,j); // plot x_i,y_i
		// Plot model
		fprintf(fs, "plot 'plotfile%d' using 1:%d lt %d with lines\n",j,p+j+2,n+j);
	}
	
	fclose(fs);
	printf("Run GNUPLOT and type the command \n");
	printf(" gnuplot> load 'plotscript' \n");
	
}
